@@ -298,7 +298,7 @@ read_devices (OssBackend *oss)
 
     for (i = 0; i < OSS_MAX_DEVICES; i++) {
         gchar   *path;
-        gboolean added_current = FALSE;
+        gboolean added_current;
 
         path = g_strdup_printf ("/dev/mixer%i", i);
 
@@ -333,6 +333,8 @@ read_device (OssBackend *oss, const gchar *path, gboolean *added)
     gchar     *bname;
     gchar     *label;
 
+    *added = FALSE;
+
     fd = g_open (path, O_RDWR, 0);
     if (fd == -1) {
         if (errno != ENOENT && errno != ENXIO)
@@ -360,11 +362,13 @@ read_device (OssBackend *oss, const gchar *path, gboolean *added)
 
     close (fd);
 
-    if ((*added = oss_device_open (device)) == TRUE)
-        add_device (oss, device);
-    else
-        g_object_unref (device);
-
+    if G_LIKELY (device != NULL) {
+        *added = oss_device_open (device);
+        if (*added == TRUE)
+            add_device (oss, device);
+        else
+            g_object_unref (device);
+    }
     return *added;
 }
 
@@ -537,11 +541,11 @@ remove_device_by_list_item (OssBackend *oss, GList *item)
                                           G_CALLBACK (remove_device),
                                           oss);
 
+    /* May emit removed signals */
     if (oss_device_is_open (device) == TRUE)
         oss_device_close (device);
 
-    g_signal_handlers_disconnect_by_func (G_OBJECT (device),
-                                          G_CALLBACK (remove_stream),
+    g_signal_handlers_disconnect_by_data (G_OBJECT (device),
                                           oss);
 
     oss->priv->devices = g_list_delete_link (oss->priv->devices, item);
@@ -554,7 +558,7 @@ remove_device_by_list_item (OssBackend *oss, GList *item)
         oss->priv->default_device = NULL;
     }
 
-    /* The list may and may not have been invalidate by device signals */
+    /* The list may have been invalidated by device signals */
     free_stream_list (oss);
 
     g_signal_emit_by_name (G_OBJECT (oss),
